@@ -1,30 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Designer of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL-EXCEPT$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "signalsloteditor.h"
 #include "signalsloteditor_p.h"
@@ -50,6 +25,8 @@
 
 QT_BEGIN_NAMESPACE
 
+using namespace Qt::StringLiterals;
+
 namespace qdesigner_internal {
 
 /*******************************************************************************
@@ -77,13 +54,13 @@ DomConnection *SignalSlotConnection::toUi() const
     QPoint tp = endPointPos(EndPoint::Target);
 
     DomConnectionHint *hint = new DomConnectionHint;
-    hint->setAttributeType(QStringLiteral("sourcelabel"));
+    hint->setAttributeType(u"sourcelabel"_s);
     hint->setElementX(sp.x());
     hint->setElementY(sp.y());
     list.append(hint);
 
     hint = new DomConnectionHint;
-    hint->setAttributeType(QStringLiteral("destinationlabel"));
+    hint->setAttributeType(u"destinationlabel"_s);
     hint->setElementX(tp.x());
     hint->setElementY(tp.y());
     list.append(hint);
@@ -413,9 +390,9 @@ void SignalSlotEditor::fromUi(const DomConnections *connections, QWidget *parent
             for (DomConnectionHint *hint : hints) {
                 QString attr_type = hint->attributeType();
                 QPoint p = QPoint(hint->elementX(), hint->elementY());
-                if (attr_type == QStringLiteral("sourcelabel"))
+                if (attr_type == "sourcelabel"_L1)
                     sp = p;
-                else if (attr_type == QStringLiteral("destinationlabel"))
+                else if (attr_type == "destinationlabel"_L1)
                     tp = p;
             }
         }
@@ -448,13 +425,13 @@ void SignalSlotEditor::fromUi(const DomConnections *connections, QWidget *parent
 static bool skipWidget(const QWidget *w)
 {
     const QString name = QLatin1String(w->metaObject()->className());
-    if (name == QStringLiteral("QDesignerWidget"))
+    if (name == "QDesignerWidget"_L1)
         return true;
-    if (name == QStringLiteral("QLayoutWidget"))
+    if (name == "QLayoutWidget"_L1)
         return true;
-    if (name == QStringLiteral("qdesigner_internal::FormWindow"))
+    if (name == "qdesigner_internal::FormWindow"_L1)
         return true;
-    if (name == QStringLiteral("Spacer"))
+    if (name == "Spacer"_L1)
         return true;
     return false;
 }
