@@ -33,11 +33,11 @@
 #include <QtCore/qdebug.h>
 
 static const char *widgetBoxRootElementC = "widgetbox";
-static const char *widgetElementC = "widget";
+static const char *wbWidgetElementC = "widget";
 static const char *uiElementC = "ui";
 static const char *categoryElementC = "category";
 static const char *categoryEntryElementC = "categoryentry";
-static const char *nameAttributeC = "name";
+static const char *wbNameAttributeC = "name";
 static const char *typeAttributeC = "type";
 static const char *iconAttributeC = "icon";
 static const char *defaultTypeValueC = "default";
@@ -50,6 +50,8 @@ enum TopLevelRole  { NORMAL_ITEM, SCRATCHPAD_ITEM, CUSTOM_ITEM };
 
 QT_BEGIN_NAMESPACE
 
+using namespace Qt::StringLiterals;
+
 static void setTopLevelRole(TopLevelRole tlr, QTreeWidgetItem *item)
 {
     item->setData(0, Qt::UserRole, QVariant(tlr));
@@ -89,7 +91,7 @@ QIcon WidgetBoxTreeWidget::iconForWidget(const QString &iconName) const
         return qdesigner_internal::qtLogoIcon();
 
     if (iconName.startsWith(QLatin1String(iconPrefixC))) {
-        const IconCache::const_iterator it = m_pluginIcons.constFind(iconName);
+        const auto it = m_pluginIcons.constFind(iconName);
         if (it != m_pluginIcons.constEnd())
             return it.value();
     }
@@ -131,7 +133,7 @@ void  WidgetBoxTreeWidget::restoreExpandedState()
 {
     using StringSet = QSet<QString>;
     QDesignerSettingsInterface *settings = m_core->settingsManager();
-    const QString groupKey = QLatin1String(widgetBoxSettingsGroupC) + QLatin1Char('/');
+    const QString groupKey = QLatin1StringView(widgetBoxSettingsGroupC) + u'/';
     m_iconMode = settings->value(groupKey + QLatin1String(widgetBoxViewModeKeyC)).toBool();
     updateViewMode();
     const auto &closedCategoryList = settings->value(groupKey + QLatin1String(widgetBoxExpandedKeyC), QStringList()).toStringList();
@@ -228,8 +230,8 @@ WidgetBoxCategoryListView *WidgetBoxTreeWidget::addCategoryView(QTreeWidgetItem
     categoryView->setViewMode(iconMode ? QListView::IconMode : QListView::ListMode);
     connect(categoryView, &WidgetBoxCategoryListView::scratchPadChanged,
             this, &WidgetBoxTreeWidget::slotSave);
-    connect(categoryView, &WidgetBoxCategoryListView::pressed,
-            this, &WidgetBoxTreeWidget::pressed);
+    connect(categoryView, &WidgetBoxCategoryListView::widgetBoxPressed,
+            this, &WidgetBoxTreeWidget::widgetBoxPressed);
     connect(categoryView, &WidgetBoxCategoryListView::itemRemoved,
             this, &WidgetBoxTreeWidget::slotScratchPadItemDeleted);
     connect(categoryView, &WidgetBoxCategoryListView::lastItemRemoved,
@@ -320,9 +322,8 @@ void WidgetBoxTreeWidget::addCustomCategories(bool replace)
     }
     // re-add
     const CategoryList customList = loadCustomCategoryList();
-    const CategoryList::const_iterator cend = customList.constEnd();
-    for (CategoryList::const_iterator it = customList.constBegin(); it != cend; ++it)
-        addCategory(*it);
+    for (const auto &c : customList)
+        addCategory(c);
 }
 
 static inline QString msgXmlError(const QString &fileName, const QXmlStreamReader &r)
@@ -359,7 +360,7 @@ bool WidgetBoxTreeWidget::readCategories(const QString &fileName, const QString
             if (tag == QLatin1String(categoryElementC)) {
                 // <category name="Layouts">
                 const QXmlStreamAttributes attributes = reader.attributes();
-                const QString categoryName = attributes.value(QLatin1String(nameAttributeC)).toString();
+                const QString categoryName = attributes.value(QLatin1String(wbNameAttributeC)).toString();
                 if (categoryName == QLatin1String(invisibleNameC)) {
                     ignoreEntries = true;
                 } else {
@@ -374,7 +375,7 @@ bool WidgetBoxTreeWidget::readCategories(const QString &fileName, const QString
                 //  <categoryentry name="Vertical Layout" icon="win/editvlayout.png" type="default">
                 if (!ignoreEntries) {
                     QXmlStreamAttributes attr = reader.attributes();
-                    const QString widgetName = attr.value(QLatin1String(nameAttributeC)).toString();
+                    const QString widgetName = attr.value(QLatin1String(wbNameAttributeC)).toString();
                     const QString widgetIcon = attr.value(QLatin1String(iconAttributeC)).toString();
                     const WidgetBoxTreeWidget::Widget::Type widgetType =
                         attr.value(QLatin1String(typeAttributeC)).toString()
@@ -461,7 +462,7 @@ bool WidgetBoxTreeWidget::readWidget(Widget *w, const QString &xml, QXmlStreamRe
                 if (name == QLatin1String(uiElementC)) {
                     startTagPosition = currentPosition;
                 } else {
-                    if (name == QLatin1String(widgetElementC)) {
+                    if (name == QLatin1String(wbWidgetElementC)) {
                         startTagPosition = currentPosition;
                         parsedWidgetTag = true;
                     } else {
@@ -471,7 +472,7 @@ bool WidgetBoxTreeWidget::readWidget(Widget *w, const QString &xml, QXmlStreamRe
                 }
             } else {
                 // We are within <ui> looking for the first <widget> tag
-                if (!parsedWidgetTag && r.name() == QLatin1String(widgetElementC)) {
+                if (!parsedWidgetTag && r.name() == QLatin1String(wbWidgetElementC)) {
                     parsedWidgetTag = true;
                 }
             }
@@ -498,9 +499,8 @@ bool WidgetBoxTreeWidget::readWidget(Widget *w, const QString &xml, QXmlStreamRe
     }
     // Oddity: Startposition is 1 off
     QString widgetXml = xml.mid(startTagPosition, endTagPosition - startTagPosition);
-    const QChar lessThan = QLatin1Char('<');
-    if (!widgetXml.startsWith(lessThan))
-        widgetXml.prepend(lessThan);
+    if (!widgetXml.startsWith(u'<'))
+        widgetXml.prepend(u'<');
     w->setDomXml(widgetXml);
     return true;
 }
@@ -508,7 +508,7 @@ bool WidgetBoxTreeWidget::readWidget(Widget *w, const QString &xml, QXmlStreamRe
 void WidgetBoxTreeWidget::writeCategories(QXmlStreamWriter &writer, const CategoryList &cat_list) const
 {
     const QString widgetbox = QLatin1String(widgetBoxRootElementC);
-    const QString name = QLatin1String(nameAttributeC);
+    const QString name = QLatin1String(wbNameAttributeC);
     const QString type = QLatin1String(typeAttributeC);
     const QString icon = QLatin1String(iconAttributeC);
     const QString defaultType = QLatin1String(defaultTypeValueC);
